mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Pavan Bobba <opensource206@gmail.com>
To: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org
Cc: Pavan Bobba <opensource206@gmail.com>
Subject: [PATCH 08/11] staging: vt6655: Type encoding info dropped from function name "CARDbRadioPowerOff"
Date: Tue, 31 Oct 2023 11:04:31 +0530	[thread overview]
Message-ID: <5b264db5a6d5ac936e02f0a7f465e648504a049e.1698730318.git.opensource206@gmail.com> (raw)
In-Reply-To: <cover.1698730318.git.opensource206@gmail.com>

function name "CARDbRadioPowerOff" updated like below:

a.type encoding info dropped from name
b.camelcase name replaced by snakecase

Issue found by checkpatch

Signed-off-by: Pavan Bobba <opensource206@gmail.com>
---
 drivers/staging/vt6655/card.c        | 4 ++--
 drivers/staging/vt6655/card.h        | 2 +-
 drivers/staging/vt6655/device_main.c | 6 +++---
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/staging/vt6655/card.h b/drivers/staging/vt6655/card.h
index ab1193799239..5ca715b415e8 100644
--- a/drivers/staging/vt6655/card.h
+++ b/drivers/staging/vt6655/card.h
@@ -52,7 +52,7 @@ u64 card_get_tsf_offset(unsigned char rx_rate, u64 qwTSF1, u64 qwTSF2);
 unsigned char card_get_pkt_type(struct vnt_private *priv);
 void CARDvSafeResetTx(struct vnt_private *priv);
 void CARDvSafeResetRx(struct vnt_private *priv);
-void CARDbRadioPowerOff(struct vnt_private *priv);
+void card_radio_power_off(struct vnt_private *priv);
 bool card_set_phy_parameter(struct vnt_private *priv, u8 bb_type);
 bool card_update_tsf(struct vnt_private *priv, unsigned char rx_rate,
 		    u64 bss_timestamp);
diff --git a/drivers/staging/vt6655/device_main.c b/drivers/staging/vt6655/device_main.c
index 2e2a8da571ab..210c94312310 100644
--- a/drivers/staging/vt6655/device_main.c
+++ b/drivers/staging/vt6655/device_main.c
@@ -454,7 +454,7 @@ static void device_init_registers(struct vnt_private *priv)
 	}
 
 	if (priv->hw_radio_off || priv->bRadioControlOff)
-		CARDbRadioPowerOff(priv);
+		card_radio_power_off(priv);
 
 	/* get Permanent network address */
 	SROMvReadEtherAddress(priv->port_offset, priv->abyCurrentNetAddr);
@@ -1349,7 +1349,7 @@ static void vnt_stop(struct ieee80211_hw *hw)
 
 	MACbShutdown(priv);
 	MACbSoftwareReset(priv);
-	CARDbRadioPowerOff(priv);
+	card_radio_power_off(priv);
 
 	device_free_td0_ring(priv);
 	device_free_td1_ring(priv);
@@ -1712,7 +1712,7 @@ static int vnt_init(struct vnt_private *priv)
 
 	priv->mac_hw = true;
 
-	CARDbRadioPowerOff(priv);
+	card_radio_power_off(priv);
 
 	return 0;
 }
diff --git a/drivers/staging/vt6655/card.c b/drivers/staging/vt6655/card.c
index 716fd3632508..7980b93d2b1e 100644
--- a/drivers/staging/vt6655/card.c
+++ b/drivers/staging/vt6655/card.c
@@ -15,7 +15,7 @@
  *      card_get_next_tbtt - Calculate Next Beacon TSF counter
  *      CARDvSetFirstNextTBTT - Set NIC Beacon time
  *      CARDvUpdateNextTBTT - Sync. NIC Beacon time
  *      CARDbRadioPowerOff - Turn Off NIC Radio Power
  *
  * Revision History:
  *      06-10-2003 Bryan YC Fan:  Re-write codes to support VT3253 spec.
@@ -351,7 +351,7 @@ bool card_set_beacon_period(struct vnt_private *priv,
  *      none
  *
  */
-void CARDbRadioPowerOff(struct vnt_private *priv)
+void card_radio_power_off(struct vnt_private *priv)
 {
 	if (priv->radio_off)
 		return;
@@ -15,7 +15,7 @@
  *      CARDvSetFirstNextTBTT - Set NIC Beacon time
  *      CARDvUpdateNextTBTT - Sync. NIC Beacon time
- *      CARDbRadioPowerOff - Turn Off NIC Radio Power
+ *      card_radio_power_off - Turn Off NIC Radio Power
  *
  * Revision History:
-- 
2.34.1


  parent reply	other threads:[~2023-10-31  5:35 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-10-31  5:34 [PATCH 00/11] Type encoding info dropped from variable and function names in NIC driver part2 Pavan Bobba
2023-10-31  5:34 ` [PATCH 01/11] staging: vt6655: Type encoding info dropped from variable name "qwBSSTimestamp" Pavan Bobba
2023-10-31  5:34 ` [PATCH 02/11] staging: vt6655: Type encoding info dropped from variable name "qwTSFOffset" Pavan Bobba
2023-10-31  5:34 ` [PATCH 03/11] staging: vt6655: Type encoding info dropped from function name "CARDqGetTSFOffset" Pavan Bobba
2023-10-31  5:34 ` [PATCH 04/11] staging: vt6655: Type encoding info dropped from function name "CARDbSetBeaconPeriod" Pavan Bobba
2023-10-31  5:34 ` [PATCH 05/11] staging: vt6655: Type encoding info dropped from variable name "wBeaconInterval" Pavan Bobba
2023-10-31  5:34 ` [PATCH 06/11] staging: vt6655: Type encoding info dropped from variable name "qwNextTBTT" Pavan Bobba
2023-10-31  5:34 ` [PATCH 07/11] staging: vt6655: Type encoding info dropped from function name "CARDqGetNextTBTT" Pavan Bobba
2023-10-31  5:34 ` Pavan Bobba [this message]
2023-10-31  5:34 ` [PATCH 09/11] staging: vt6655: Type encoding info dropped from function name "CARDvSafeResetTx" Pavan Bobba
2023-10-31  5:34 ` [PATCH 10/11] staging: vt6655: Type encoding info dropped from variable name "pCurrTD" Pavan Bobba
2023-10-31  5:34 ` [PATCH 11/11] staging: vt6655: Type encoding info dropped from variable name "apTailTD" Pavan Bobba
2023-11-04 11:39 ` [PATCH 00/11] Type encoding info dropped from variable and function names in NIC driver part2 Philipp Hortmann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=5b264db5a6d5ac936e02f0a7f465e648504a049e.1698730318.git.opensource206@gmail.com \
    --to=opensource206@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®